@@ -19,20 +19,34 @@ class PaymentechResource(FieldContainer, metaclass=DeclarativeClass):
             child.text = value
 
         if inject:
-            for key, value in inject:
+            for key, value in inject.items():
                 child = ElementTree.SubElement(payload, key)
                 child.text = value
 
         return str(ElementTree.tostring(payload, 'unicode'))
 
-    def save(self):
+    def transact(self):
         authentication = {
             "OrbitalConnectionUsername": paymentech.configuration.get("username"),
             "OrbitalConnectionPassword": paymentech.configuration.get("password"),
+            "BIN": paymentech.configuration.get("bin"),
             "CustomerBin": paymentech.configuration.get("bin"),
             "CustomerMerchantId": paymentech.configuration.get("merchant")
         }
         payload = self.serialize(inject=authentication)
-        response = service.request(payload)
+        result = service.request(payload)
+        response = self.process_result(result)
 
         return response
+
+    @staticmethod
+    def process_result(result):
+        result = ElementTree.fromstring(result)
+        elements = result[0]
+
+        dataset = {
+            child.tag: child.text
+            for child in elements
+        }
+
+        return dataset
